@@ -1,12 +1,13 @@
 package Git::FastExport::Block;
+{
+  $Git::FastExport::Block::VERSION = '0.09';
+}
 
 use strict;
 use warnings;
 
 my $LF = "\012";
 
-our $VERSION = '0.07';
-
 my %fields = (
     commit     => [qw( mark author committer data from merge files )],
     tag        => [qw( from tagger data )],
@@ -37,23 +38,31 @@ sub as_string {
     return $string .= $self->{footer} || '';
 }
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
 Git::FastExport::Block - A block in a fast-export stream
 
-=head1 SYNOSPSIS
+=head1 VERSION
+
+version 0.09
+
+=head1 SYNOPSIS
+
+This package is used internally by L<Git::FastExport>.
 
 =head1 DESCRIPTION
 
-C<Git::FastExport::Block> represents blocks from a B<git-fast-export>
+L<Git::FastExport::Block> represents blocks from a B<git fast-export>
 stream.
 
 Internally, it is a simple hash with keys pointing either to a string
 or a reference to an array of strings, which makes it very
-easing to edit (when obtained via C<Git::FastExport> C<next_block()>
-method) or create.
+easing to edit (when obtained via L<Git::FastExport> C<next_block()>
+method) or create blocks in a B<git fast-export> stream.
 
 The following two keys are pointing to strings:
 
@@ -108,27 +117,40 @@ tagger
 
 =back
 
-Of course, which keys are present depend on the type of the block, 
+Of course, which keys are present depend on the type of the block,
 which is conveniently stored in the C<type> key.
 
+All other keys are ignored.
+
 =head1 METHODS
 
-A C<Git::FastExport::Block> structure is meant to be used as a hash,
+A L<Git::FastExport::Block> structure is meant to be used as a hash,
 and is not protected by an accessor/mutator interface.
+Or a constructor.
 
-However, the module provides a method for ouputing blocks:
+However, the module provides a method for outputing blocks:
 
 =over 4
 
 =item as_string()
 
-Return the block as a string suitable for B<git-fast-import>.
+Return the block as a string suitable for B<git fast-import>.
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Git-FastExport or by email to
+bug-git-fastexport@rt.cpan.org.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
-Philippe Bruhat (BooK), C<< <book@cpan.org> >>.
+Philippe Bruhat (BooK) <book@cpan.org>
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -138,7 +160,7 @@ under the same terms as Perl itself.
 
 =head1 COPYRIGHT
 
-Copyright 2008 Philippe Bruhat (BooK), All Rights Reserved.
+Copyright 2008-2013 Philippe Bruhat (BooK), All Rights Reserved.
 
 =head1 LICENSE
 
@@ -147,3 +169,8 @@ under the same terms as Perl itself.
 
 =cut
 
+
+__END__
+
+# ABSTRACT: A block in a fast-export stream
+
